#include <iostream>
#include <vector>

class ISS
{
public:
    double beta;
    double yaw;
    double maxFront, maxBack;
    double maxFront2, maxBack2;
    bool inverted;
    bool unknown;
    bool correction;
    double ssarj_diff;
    double psarj_diff;
    static const double angles_75[92];
    static const double speeds_75[92];
    static const double angles_74[92];
    static const double speeds_74[92];
    static const double angles_73[92];
    static const double speeds_73[92];
    static const double angles_72[92];
    static const double speeds_72[92];
    static const double angles_71[92];
    static const double speeds_71[92];
    static const double angles_70[92];
    static const double speeds_70[92];

    static const double angles__75[92];
    static const double speeds__75[92];
    static const double angles__74[92];
    static const double speeds__74[92];
    static const double angles__73[92];
    static const double speeds__73[92];
    static const double angles__72[92];
    static const double speeds__72[92];
    static const double angles__71[92];
    static const double speeds__71[92];
    static const double angles__70[92];
    static const double speeds__70[92];

    const double* back_speed;
    const double* back_angle;
public:
    double getInitialOrientation(double beta);
    std::vector<double> getStateAtMinute(int minute);
};

double ISS::getInitialOrientation(double beta) {
    this->beta = beta;
    inverted = beta < 0;
    correction = false;
    unknown = false;
    ssarj_diff = 0;
    psarj_diff = 0;
    switch ((int) beta) {
    case 75: //Score = 147646.8470455654; 147753.63632704096; 146619.98632774362; 146427.39969943944
        //No naive correction improvement
        //maxFront = 9; maxBack = -19;
        //maxBack = -16.5; maxFront = 10.9;
        maxBack2 = -16.5; maxFront2 = 10.9;
        psarj_diff = 180;
        //ssarj_diff = 0;
        back_speed = speeds_75; back_angle = angles_75;
        maxBack = 18.3; maxFront = -7.9;
        //maxBack2 = -18.5; maxFront2 = 7.9;
        //147634.691018297
        //149420.87299297887
        break;

    case 74: //Score = 152177.87417508475; 152285.97547187758; 151195.71958277334; 151100.96089024
        //No naive correction improvement
        //maxFront = 2; maxBack = -16;
        //maxBack = -18.9; maxFront = 3.9;
        maxBack2 = -18; maxFront2 = 4;
        psarj_diff = 180;
        //ssarj_diff = 1;
        back_speed = speeds_74; back_angle = angles_74;
        maxBack = 21.1; maxFront = -0.1;
        //maxBack2 = 21.1; maxFront2 = -0.1;
        //152193.3745905561
        //154065.7938960904
        break;

    case 73: //Score = 156730.33490865122; 156837.87709695392; 155409.0296204985; 155464.43777079377*
        //No naive correction improvement
        //maxFront = -10; maxBack = -22;
        maxBack2 = -20.3; maxFront2 = -5;
        psarj_diff = 180; //ssarj_diff = 1;
        back_speed = speeds_73; back_angle = angles_73;
        maxBack = 20; maxFront = 11.3;
        //156446.1568700968
        //158324.35043362927
        break;

    case 72: //Score = 158243.86596211512; 158365.19711771247; 157383.09862552374
        //No naive correction improvement
        maxBack = -18; maxFront = -18;
        maxBack2 = -18; maxFront2 = -18;
        back_speed = speeds_72; back_angle = angles_72;
        //158357.99905657323
        //160218.83079427836
        break;

    case 71: //Score = 158759.18738233508; 158870.65091080885; 157849.75150079647
        //No naive correction improvement
        maxBack = -19; maxFront = -19;
        maxBack2 = -19; maxFront2 = -19;
        back_speed = speeds_71; back_angle = angles_71;
        //158870.7777319441
        //160600.10505470244
        break;

    case 70: //Score = 159235.25953617663; 159453.95951745386; 158278.37628770122
        //Found solution does produce longeron failure on back panels - maxFront -21, maxBack -22, but works for SSARJ +5
        //cat log | sed "s/(/( /" | sort -nk 11 | grep "0000)$"
        //No naive correction improvement
        maxBack = -20; maxFront = -20;
        maxBack2 = -20; maxFront2 = -20;
        back_speed = speeds_70; back_angle = angles_70;
        //159339.03555361598
        //maxFront = -21; maxBack = -22;
        //ssarj_diff = 5;
        //161001.35854228048
        break;

    case -75: //Score = 146738.73797229296; 146833.07320072825; 146619.98632774362; 146693.59229079876*
        //Correction improvement - back -0.7 - 146777.7085290651
        //maxFront = -8; maxBack = 22.3;
        maxBack = 21.1; maxFront = -9.2;
        maxBack2 = 21.1; maxFront2 = -9.2;
        back_speed = speeds__75; back_angle = angles__75;
        //146693.59229079876
        break;

    case -74: //Score = 151548.3234100629; 151875.022238489; 151195.71958277334; 151225.93277782973*
        //No naive correction improvement
        //maxFront = -1; maxBack = 17;
        maxBack = 20.1; maxFront = -2.1;
        maxBack2 = 20.1; maxFront2 = -2.1;
        back_speed = speeds__74; back_angle = angles__74;
        //151225.93277782973
        break;

    case -73: //Score = 155766.7123576515; 156008.74755268893; 155409.0296204985; 155443.64147073403*
        //No naive correction improvement
        //maxFront = 10; maxBack = 19;
        maxBack = 21.1; maxFront = 7.8;
        maxBack2 = 21.1; maxFront2 = 7.8;
        back_speed = speeds__73; back_angle = angles__73;
        //155443.64147073403
        break;

    case -72: //Score = 157296.24587134225; 157387.56481993274; 157383.09862552374
        //No naive correction improvement
        maxBack = 18; maxFront = 18;
        maxBack2 = 18; maxFront2 = 18;
        back_speed = speeds__72; back_angle = angles__72;
        //157383.09862552374
        //159806.9862412168
        break;

    case -71: //Score = 157767.93894873263; 157853.8242431642; 157849.75150079647
        //No naive correction improvement
        maxBack = 19; maxFront = 19;
        maxBack2 = 19; maxFront2 = 19;
        back_speed = speeds__71; back_angle = angles__71;
        //157849.75150079647
        break;

    case -70: //Score = 158239.45745055724; 157907.5996245371; 158278.37628770122*; 158277.71509308898
        //No naive correction improvement
        //maxFront = 20; maxBack = 20;
        maxBack2 = 18; maxFront2 = 21;
        maxBack = -18.3; maxFront = -20.4;
        ssarj_diff = 178;
        back_speed = speeds__70; back_angle = angles__70;
        //158284.54332902233
        break;

    default:
        maxFront = 0; maxBack = 0;
        unknown = true;
        break;
    }

    this->yaw = 0;
    return this->yaw;
}

std::vector<double> ISS::getStateAtMinute(int minute) {
    std::vector<double> ret(20);
    // 2B  4A                  1A 3B
    //
    //         PSARJ    SSARJ
    //
    // 4B  2A                  3A 1B
    //
    // Visualisation from left to right
#if 0
    if (minute == 0 && unknown) {
        double power = 0;
        std::ofstream log;
        log.open("log", std::ios_base::app);
        assert(log.is_open());
        //log << "minute " << minute << std::endl;
//#define TIME
#ifdef TIME
        std::ofstream log_time;
        log_time.open("log_time", std::ios_base::app);
        bool native = true;
#endif
        library l;
        for (int i = -45; i <= 45; i ++) {
#ifdef TIME
            timespec tS;
            tS.tv_sec = 0;
            tS.tv_nsec = 0;
            clock_settime(CLOCK_PROCESS_CPUTIME_ID, &tS);
#endif
            //clock_t begin = clock();
            for (int j = -45; j <= 45; j ++) {
                if (inverted) {
                    double bgas[8] = { 180 - j, 0, 180 + j, 0, 180 + i, 0, 180 - i, 0};
                    /*library */l.callMinute(minute, beta, yaw, 0, 0, bgas,
                                             library::A1 | library::A3 | library::B1 | library::B3
                                             /*, native*/);
                    log << "i " << i << " j " << j << " power: ";
                    log << l.power[0] << " " << l.power[2] << " " << l.power[4] << " " << l.power[6] << " ";
                    log << "(" << (l.power[0] + l.power[2] + l.power[4] + l.power[6]) << " ";
                    log << l.shadowed_bga[0] << l.shadowed_bga[2] << l.shadowed_bga[4] << l.shadowed_bga[6] << ")" << std::endl;
                    if ( (!l.shadowed_bga[0] && !l.shadowed_bga[2] && !l.shadowed_bga[4] && !l.shadowed_bga[6]) &&
                         (l.power[0] > 8.9 && l.power[2] > 8.9 && l.power[4] > 8.9 && l.power[6] > 8.9) &&
                         (l.power[0] + l.power[2] + l.power[4] + l.power[6]) > power
                       ) {
                        maxFront = i; maxBack = j;
                        power = (l.power[0] + l.power[2] + l.power[4] + l.power[6]);
                    }
                    /*log << "i " << i << " j " << j << " power: ";// << l.power[1]  + l.power[3] << std::endl;
                    log << " " << l.power[0] << " " << l.power[6] << " (" << l.power[0] + l.power[6] <<  ", " << l.shadowed_bga[0] << l.shadowed_bga[6] << "), ";
                    log << l.power[2] << " " << l.power[4] << " (" << l.power[2] + l.power[4] << ", " << l.shadowed_bga[2] << l.shadowed_bga[4] << ")" << std::endl;
                    if (l.power[0] > 8900 && !l.shadowed_bga[0] && !l.shadowed_bga[6] && (l.power[0] + l.power[6]) > power) {
                        maxFront = i; maxBack = j;
                        power = (l.power[0] + l.power[6]);
                    }
                    if (l.power[2] > 8900 && !l.shadowed_bga[2] && !l.shadowed_bga[4] && (l.power[2] + l.power[4]) > power) {
                        maxFront = i; maxBack = j + 1;
                        power = (l.power[2] + l.power[4]);
                    }*/
                }
                else {
                    double bgas[8] = { 0, 180 + j, 0, 180 - j, 0, 180 - i, 0, 180 + i};
                    /*library */l.callMinute(minute + 10, beta, yaw, 30, 30, bgas,
                                             library::A2 | library::A4 | library::B2 | library::B4
                                             /*, native*/);
                    log << "i " << i << " j " << j << " power: ";
                    log << l.power[1] << " " << l.power[3] << " " << l.power[5] << " " << l.power[7] << " ";
                    log << "(" << (l.power[1] + l.power[3] + l.power[5] + l.power[7]) << " ";
                    log << l.shadowed_bga[1] << l.shadowed_bga[3] << l.shadowed_bga[5] << l.shadowed_bga[7] << ")" << std::endl;
                    if ( (!l.shadowed_bga[1] && !l.shadowed_bga[3] && !l.shadowed_bga[5] && !l.shadowed_bga[7]) &&
                         (l.power[1] > 8.9 && l.power[3] > 8.9 && l.power[5] > 8.9 && l.power[7] > 8.9) &&
                         (l.power[1] + l.power[3] + l.power[5] + l.power[7]) > power
                       ) {
                        maxFront = i; maxBack = j;
                        power = (l.power[1] + l.power[3] + l.power[5] + l.power[7]);
                    }
                    /*
                    log << "i " << i << " j " << j << " power: ";// << l.power[1]  + l.power[3] << std::endl;
                    log << " " << l.power[1] << " " << l.power[7] << " (" << l.power[1] + l.power[7] <<  ", " << l.shadowed_bga[1] << l.shadowed_bga[7] << "), ";
                    log << l.power[3] << " " << l.power[5] << " (" << l.power[3] + l.power[5] << ", " << l.shadowed_bga[3] << l.shadowed_bga[5] << ")" << std::endl;
                    if (l.power[1] > 8900 && !l.shadowed_bga[1] && !l.shadowed_bga[7] && (l.power[1] + l.power[7]) > power) {
                        maxFront = i; maxBack = j;
                        power = (l.power[1] + l.power[7]);
                    }
                    if (l.power[3] > 8900 && !l.shadowed_bga[3] && !l.shadowed_bga[5] && (l.power[3] + l.power[5]) > power) {
                        maxFront = i; maxBack = j + 1;
                        power = (l.power[3] + l.power[5]);
                    }
                    */
                }
            }
#ifdef TIME
            //clock_t end = clock();
            clock_gettime(CLOCK_PROCESS_CPUTIME_ID, &tS);
            if (!native) {
                //log_time << "old fashioned: " << (double) (double(end - begin) / CLOCKS_PER_SEC) << std::endl;
                log_time << "old fashioned: " << tS.tv_sec << " " << tS.tv_nsec << std::endl;
                log_time.close();
                break;
            }
            else {
                i = -46;
                //log_time << "native: " << (double) (double(end - begin) / CLOCKS_PER_SEC) << std::endl;
                log_time << "native: "  << tS.tv_sec << " " << tS.tv_nsec << std::endl;
                native = false;
            }
#endif
        }
#ifdef TIME
        log_time.close();
#endif
        log << "maxBack: " << maxBack <<  " maxFront: " << maxFront << std::endl;
        //log << "minute " << minute << ": max " << max << " power " << power << std::endl;
        log.close();
    }

    if (minute == 0 && correction) {
        double power = 0;
        double correctionFront = 0;
        double correctionBack = 0;
        std::ofstream log;
        log.open("log", std::ios_base::app);
        assert(log.is_open());
        library l;
        for (double i = -0.9; i < 1.0; i += 0.1) {
            for (double j = -0.9; j < 1.0; j += 0.1) {
                if (inverted) {
                    double bgas[8] = { 180 - maxBack - j, 0, 180 + maxBack + j, 0, 180 + maxFront + i, 0, 180 - maxFront - i, 0};
                    l.callMinute(minute, beta, yaw, 0, 0, bgas,
                              library::A1 | library::A3 | library::B1 | library::B3);
                    log << "i " << i << " j " << j << " power: ";
                    log << l.power[0] << " " << l.power[2] << " " << l.power[4] << " " << l.power[6] << " ";
                    log << "(" << (l.power[0] + l.power[2] + l.power[4] + l.power[6]) << " ";
                    log << l.shadowed_bga[0] << l.shadowed_bga[2] << l.shadowed_bga[4] << l.shadowed_bga[6] << ")" << std::endl;
                    if ( (!l.shadowed_bga[0] && !l.shadowed_bga[2] && !l.shadowed_bga[4] && !l.shadowed_bga[6]) &&
                         (l.power[0] > 8.9 && l.power[2] > 8.9 && l.power[4] > 8.9 && l.power[6] > 8.9) &&
                         (l.power[0] + l.power[2] + l.power[4] + l.power[6]) > power
                       ) {
                        maxFront = i; maxBack = j;
                        power = (l.power[0] + l.power[2] + l.power[4] + l.power[6]);
                    }
                    /*log << "i " << i << " j " << j << " power: ";// << l.power[1]  + l.power[3] << std::endl;
                    log << " " << l.power[0] << " " << l.power[6] << " (" << l.power[0] + l.power[6] <<  ", " << l.shadowed_bga[0] << l.shadowed_bga[6] << "), ";
                    log << l.power[2] << " " << l.power[4] << " (" << l.power[2] + l.power[4] << ", " << l.shadowed_bga[2] << l.shadowed_bga[4] << ")" << std::endl;
                    if (l.power[0] > 8900 && !l.shadowed_bga[0] && !l.shadowed_bga[6] && (l.power[0] + l.power[6]) > power) {
                        correctionFront = i; correctionBack = j;
                        power = (l.power[0] + l.power[6]);
                    }
                    if (l.power[2] > 8900 && !l.shadowed_bga[2] && !l.shadowed_bga[4] && (l.power[2] + l.power[4]) > power) {
                        correctionFront = i; correctionBack = j + 0.1;
                        power = (l.power[2] + l.power[4]);
                    }*/
                }
                else {
                    double bgas[8] = { 0, 180 + maxBack + j, 0, 180 - maxBack - j, 0, 180 - maxFront - i, 0, 180 + maxFront + i};
                    l.callMinute(minute, beta, yaw, 0, 0, bgas,
                              library::A2 | library::A4 | library::B2 | library::B4);
                    log << "i " << i << " j " << j << " power: ";
                    log << l.power[1] << " " << l.power[3] << " " << l.power[5] << " " << l.power[7] << " ";
                    log << "(" << (l.power[1] + l.power[3] + l.power[5] + l.power[7]) << " ";
                    log << l.shadowed_bga[1] << l.shadowed_bga[3] << l.shadowed_bga[5] << l.shadowed_bga[7] << ")" << std::endl;
                    if ( (!l.shadowed_bga[1] && !l.shadowed_bga[3] && !l.shadowed_bga[5] && !l.shadowed_bga[7]) &&
                         (l.power[1] > 8.9 && l.power[3] > 8.9 && l.power[5] > 8.9 && l.power[7] > 8.9) &&
                         (l.power[1] + l.power[3] + l.power[5] + l.power[7]) > power
                       ) {
                        maxFront = i; maxBack = j;
                        power = (l.power[1] + l.power[3] + l.power[5] + l.power[7]);
                    }
                    /*log << "i " << i << " j " << j << " power: ";// << l.power[1]  + l.power[3] << std::endl;
                    log << " " << l.power[1] << " " << l.power[7] << " (" << l.power[1] + l.power[7] <<  ", " << l.shadowed_bga[1] << l.shadowed_bga[7] << "), ";
                    log << l.power[3] << " " << l.power[5] << " (" << l.power[3] + l.power[5] << ", " << l.shadowed_bga[3] << l.shadowed_bga[5] << ")" << std::endl;
                    if (l.power[1] > 8900 && !l.shadowed_bga[1] && !l.shadowed_bga[7] && (l.power[1] + l.power[7]) > power) {
                        correctionFront = i; correctionBack = j;
                        power = (l.power[1] + l.power[7]);
                    }
                    if (l.power[3] > 8900 && !l.shadowed_bga[3] && !l.shadowed_bga[5] && (l.power[3] + l.power[5]) > power) {
                        correctionFront = i; correctionBack = j + 0.1;
                        power = (l.power[3] + l.power[5]);
                    }*/
                }
            }
        }
        log << "correctionBack: " << correctionBack <<  " correctionFront: " << correctionFront << std::endl;
        maxFront += correctionFront;
        maxBack += correctionBack;
        //log << "minute " << minute << ": max " << max << " power " << power << std::endl;
        log.close();
    }

    //double bgas[8] = { 180, 0, 180, 0, 180, 0, 180, 0};
    //double bgas[8] = { 0, 180 - 20, 0, 180 + 20, 0, 180 + 20, 0, 180 - 20};
    //library l(0, beta, yaw, 0, 0, bgas);

    //Not needed - best for 0
    /*int initial = 0;
    if (minute == 0) {
        std::ofstream log;
        log.open("log", std::ios_base::app);
        double power = 0;
        for (int i = 0; i < 360; i ++) {

            double bgas[8] = { 0, 180 + maxBack, 0, 180 - maxBack, 0, 180 - maxFront, 0, 180 + maxFront};
            library l((double) i, beta, yaw, 90, 0, bgas);
            log << "angle: " << i << ": " << l.power[1] << " " << l.power[3] << " " << l.power[5] << " "
                  << l.power[7] << " (" << (l.power[1] + l.power[3] + l.power[5] + l.power[7]) << ")" << std::endl;
            if (l.power[1] + l.power[3] + l.power[5] + l.power[7] > power) {
                power = l.power[1] + l.power[3] + l.power[5] + l.power[7];
                initial = i;
            }
        }
        log << "initial: " << initial << std::endl;
        log.close();
    }*/
#endif
    ret[0] = minute * (360.0 / 92.0) + ssarj_diff ; //SSARJ position
    ret[1] = 0;
    ret[2] = 360.0 - minute * (360.0 / 92.0) + psarj_diff ; //PSARJ position
    ret[3] = 0;
    if (inverted) {
        ret[2] = back_angle[minute] + 360.0;
        ret[3] = back_speed[minute];
    }
    else {
        ret[0] = back_angle[minute] + 360.0;
        ret[1] = back_speed[minute];
    }
    ret[4] = (inverted ? 180 - maxBack : 360 - maxFront2); //BGA 1A -> 6.3 KW
    ret[5] = 0;
    ret[6] = (inverted ? 360 + maxFront2 : 180 + maxBack); //BGA 2A -> 6.4 KW
    ret[7] = 0;
    ret[8] = (inverted ? 180 + maxBack : 360 + maxFront2); //BGA 3A -> 6.7 KW
    ret[9] = 0;
    ret[10] = (inverted ? 360 - maxFront2 : 180 - maxBack); //BGA 4A -> 8.9 KW
    ret[11] = 0;
    ret[12] = (inverted ? 180 + maxFront : 360 + maxBack2); //BGA 1B -> 5.5 KW
    ret[13] = 0;
    ret[14] = (inverted ? 360 - maxBack2 : 180 - maxFront); //BGA 2B -> 8.1 KW
    ret[15] = 0;
    ret[16] = (inverted ? 180 - maxFront : 360 - maxBack2); //BGA 3B -> 4.4 KW
    ret[17] = 0;
    ret[18] = (inverted ? 360 + maxBack2 : 180 + maxFront); //BGA 4B -> 4.3 KW
    ret[19] = 0;
    for (int i = 0; i < 20; i += 2) {
        while (ret[i] >= 360.0) ret[i] -= 360.0;
    }
    return ret;
}

/*const double ISS::angles_75[] = {9, 12.913, 17.8261, 21.7391, 23.6522, 24.5652, 31.4783, 25.3913, 25.3043, 33.2174, 42.1304, 47.0435, 47.9565, 48.8696, 50.7826, 53.6957, 54.6087, 57.5217, 66.4348, 75.3478, 84.2609, 86.1739, 84.087, 86, 89.913, 93.8261, 102.739, 109.652, 118.565, 117.478, 118.391, 119.304, 119.217, 120.13, 123.043, 127.957, 136.87, 145.783, 147.696, 147.609, 148.522, 153.435, 155.348, 164.261, 166.174, 166.087, 170, 174.913, 181.826, 182.739, 185.652, 194.565, 203.478, 212.391, 221.304, 222.217, 229.13, 233.043, 235.957, 240.87, 244.783, 246.696, 252.609, 256.522, 260.435, 263.348, 268.261, 271.174, 273.087, 271, 271.913, 270.826, 271.739, 276.652, 285.565, 290.478, 290.391, 291.304, 295.217, 300.13, 305.043, 306.957, 315.87, 324.783, 333.696, 342.609, 346.522, 350.435, 354.348, 356.261, 362.174, 366.087};
const double ISS::speeds_75[] = {0.04, 0.13, -0.05, 0.1, -0.11, 0.12, 0.01, -0.14, 0.05, 0.13, 0.13, -0.05, -0.06, -0.05, -0.03, -0.02, -0.09, 0.13, 0.13, 0.13, 0.13, -0.1, -0.11, 0.11, -0.07, 0.13, 0.13, 0.13, 0.13, -0.13, 0.1, -0.04, -0.1, 0.01, -0.05, 0.13, 0.13, 0.13, 0.01, -0.13, 0.13, -0.05, 0.13, 0.13, -0.11, 0.03, -0.04, 0.12, 0.01, -0.09, 0.13, 0.13, 0.13, 0.13, 0.13, 0.03, 0.07, -0.01, -0.04, 0.11, -0.07, 0.11, -0.02, 0.11, -0.07, 0.13, -0.05, 0.1, -0.11, 0.05, -0.12, -0.06, -0.05, 0.13, 0.13, -0.01, -0.12, 0.05, -0.05, 0.13, -0.05, 0.13, 0.13, 0.13, 0.13, 0.13, -0.06, 0.07, -0.06, -0.02, 0.11, -0.07};//power 6.23157e+06
const double ISS::angles_74[] = {9, 12.913, 17.8261, 21.7391, 24.6522, 25.5652, 25.4783, 26.3913, 25.3043, 26.2174, 34.1304, 43.0435, 48.9565, 49.8696, 50.7826, 52.6957, 55.6087, 57.5217, 60.4348, 69.3478, 78.2609, 87.1739, 91.087, 92, 90.913, 99.8261, 104.739, 106.652, 109.565, 114.478, 117.391, 119.304, 120.217, 120.13, 123.043, 130.957, 139.87, 148.783, 149.696, 148.609, 149.522, 151.435, 155.348, 158.261, 165.174, 166.087, 170, 176.913, 177.826, 183.739, 185.652, 194.565, 203.478, 212.391, 221.304, 224.217, 225.13, 233.043, 236.957, 239.87, 241.783, 248.696, 252.609, 256.522, 260.435, 263.348, 268.261, 269.174, 273.087, 271, 277.913, 286.826, 287.739, 287.652, 287.565, 287.478, 288.391, 291.304, 298.217, 302.13, 303.043, 306.957, 314.87, 323.783, 332.696, 341.609, 346.522, 350.435, 354.348, 358.261, 362.174, 364.087};
const double ISS::speeds_74[] = {0.13, 0, 0.02, -0.03, -0.02, -0.09, -0.05, -0.06, -0.12, 0.05, 0.13, 0.13, -0.02, -0.09, -0.02, -0.06, 0.03, -0.09, 0.13, 0.13, 0.13, 0.13, 0.1, -0.13, 0.13, 0.13, -0.03, -0.05, 0.01, 0.01, -0.05, -0.03, -0.08, -0.07, 0.05, 0.13, 0.13, 0.13, -0.13, 0.02, -0.11, 0.11, -0.07, 0.12, 0.01, -0.07, 0.12, 0.01, 0.11, -0.02, 0.13, 0.13, 0.13, 0.13, 0.13, -0.09, 0.13, 0.05, 0.06, -0.08, 0.02, 0.11, -0.07, 0.11, -0.07, 0.13, -0.05, 0.11, -0.07, 0.01, 0.13, 0.13, -0.09, -0.06, -0.09, -0.05, -0.06, 0.03, 0.07, -0.06, -0.05, 0.05, 0.13, 0.13, 0.13, 0.13, -0.03, 0.02, -0.03, 0.02, -0.03, -0.05};//power 6.44704e+06
const double ISS::angles_73[] = {9, 11.913, 17.8261, 21.7391, 24.6522, 26.5652, 26.4783, 27.3913, 27.3043, 35.2174, 37.1304, 46.0435, 50.9565, 51.8696, 53.7826, 53.6957, 54.6087, 57.5217, 61.4348, 70.3478, 79.2609, 87.1739, 89.087, 92, 97.913, 101.826, 103.739, 97.6522, 102.565, 111.478, 117.391, 112.304, 116.217, 120.13, 125.043, 133.957, 142.87, 149.783, 150.696, 150.609, 150.522, 151.435, 155.348, 162.261, 163.174, 166.087, 170, 175.913, 177.826, 181.739, 185.652, 189.565, 198.478, 207.391, 216.304, 225.217, 227.13, 228.043, 236.957, 239.87, 244.783, 247.696, 251.609, 255.522, 259.435, 263.348, 267.261, 270.174, 274.087, 275, 283.913, 283.826, 283.739, 283.652, 284.565, 284.478, 287.391, 291.304, 296.217, 300.13, 304.043, 312.957, 321.87, 330.783, 338.696, 342.609, 346.522, 350.435, 354.348, 358.261, 360.174, 360.087};
const double ISS::speeds_73[] = {0.13, -0.02, 0.11, -0.07, 0.1, -0.11, 0.1, -0.13, 0.13, 0.05, 0.13, 0.13, -0.05, -0.05, -0.03, -0.11, 0.04, -0.07, 0.13, 0.13, 0.13, 0.05, -0.09, 0.11, -0.02, 0.1, -0.11, -0.05, 0.13, 0.13, -0.02, -0.05, 0.05, -0.05, 0.13, 0.13, 0.13, 0.01, -0.04, -0.1, -0.04, -0.07, 0.12, 0.01, 0.02, -0.06, 0.08, -0.01, -0.07, 0.11, -0.07, 0.13, 0.13, 0.13, 0.13, 0.13, -0.11, 0.13, 0.13, 0.09, -0.04, 0.11, -0.07, 0.11, -0.07, 0.11, -0.07, 0.11, -0.07, 0.13, 0.13, -0.03, -0.11, -0.02, -0.09, -0.06, 0.03, -0.04, 0.11, -0.07, 0.13, 0.13, 0.13, 0.13, 0.05, 0.07, -0.06, 0.07, -0.06, 0.1, -0.11, 0.13};//power 6.65028e+06
const double ISS::angles_72[] = {9, 10.913, 17.8261, 21.7391, 25.6522, 27.5652, 28.4783, 28.3913, 28.3043, 28.2174, 37.1304, 39.0435, 46.9565, 52.8696, 54.7826, 54.6957, 55.6087, 56.5217, 62.4348, 64.3478, 73.2609, 82.1739, 91.087, 94, 97.913, 101.826, 104.739, 97.6522, 102.565, 111.478, 117.391, 116.304, 124.217, 125.13, 125.043, 127.957, 136.87, 145.783, 151.696, 145.609, 148.522, 153.435, 159.348, 168.261, 168.174, 167.087, 170, 173.913, 177.826, 186.739, 186.652, 189.565, 198.478, 207.391, 216.304, 225.217, 229.13, 230.043, 231.957, 240.87, 244.783, 248.696, 251.609, 253.522, 260.435, 263.348, 267.261, 272.174, 276.087, 280, 280.913, 279.826, 280.739, 280.652, 280.565, 283.478, 287.391, 294.304, 295.217, 299.13, 303.043, 311.957, 320.87, 329.783, 338.696, 342.609, 346.522, 350.435, 354.348, 358.261, 359.174, 361.087};
const double ISS::speeds_72[] = {0.09, 0.12, 0.01, 0.11, -0.07, 0.1, -0.13, 0.11, -0.15, 0.13, 0.13, 0.07, 0.09, 0.1, -0.11, 0.1, -0.13, 0.11, -0.02, 0.13, 0.13, 0.13, 0.13, 0.07, -0.06, 0.1, -0.09, -0.05, 0.13, 0.13, -0.02, 0.1, 0.06, -0.06, -0.09, 0.13, 0.13, 0.13, -0.02, -0.07, 0.05, -0.02, 0.13, 0.13, -0.09, -0.09, 0.11, -0.07, 0.13, 0.13, -0.09, 0.13, 0.13, 0.13, 0.13, 0.13, 0.02, -0.11, 0.13, 0.13, -0.06, 0.1, -0.09, 0.12, 0.01, -0.05, 0.06, -0.03, 0.02, -0.03, -0.08, -0.1, 0.01, -0.13, 0.04, -0.07, 0.12, 0.01, 0.11, -0.07, 0.13, 0.13, 0.13, 0.13, 0.13, 0, -0.01, 0, -0.01, 0, -0.1, 0.07};//power 6.795e+06
const double ISS::angles_71[] = {9, 13.913, 17.8261, 21.7391, 25.6522, 29.5652, 29.4783, 30.3913, 30.3043, 30.2174, 31.1304, 40.0435, 41.9565, 49.8696, 53.7826, 56.6957, 58.6087, 58.5217, 60.4348, 67.3478, 72.2609, 81.1739, 90.087, 94, 98.913, 101.826, 104.739, 98.6522, 102.565, 111.478, 117.391, 118.304, 127.217, 127.13, 127.043, 127.957, 131.87, 140.783, 149.696, 155.609, 155.522, 155.435, 158.348, 167.261, 169.174, 169.087, 170, 173.913, 178.826, 187.739, 187.652, 189.565, 198.478, 207.391, 216.304, 225.217, 229.13, 232.043, 232.957, 240.87, 244.783, 248.696, 252.609, 256.522, 259.435, 264.348, 268.261, 272.174, 276.087, 278, 277.913, 277.826, 277.739, 277.652, 279.565, 283.478, 287.391, 293.304, 295.217, 301.13, 310.043, 318.957, 327.87, 334.783, 338.696, 342.609, 346.522, 350.435, 354.348, 358.261, 358.174, 360.087};
const double ISS::speeds_71[] = {0.13, -0.05, 0.11, -0.07, 0.11, -0.07, 0.1, -0.13, 0.01, -0.13, 0.13, 0.13, 0.07, 0.09, 0.01, -0.05, -0.03, -0.11, 0.12, 0.01, 0.13, 0.13, 0.13, 0.13, -0.05, 0.1, -0.09, -0.07, 0.13, 0.13, -0.02, 0.13, 0.13, -0.1, -0.04, -0.07, 0.13, 0.13, 0.13, -0.02, -0.06, -0.09, 0.13, 0.13, -0.01, -0.12, 0.05, -0.05, 0.13, 0.13, -0.11, 0.13, 0.13, 0.13, 0.13, 0.13, 0.1, -0.09, 0.13, 0.05, 0.11, -0.07, 0.11, -0.07, 0.13, -0.05, 0.07, -0.06, 0.1, -0.11, -0.03, -0.11, -0.03, -0.11, 0.11, -0.07, 0.11, -0.02, -0.02, 0.13, 0.13, 0.13, 0.13, 0.01, 0.02, -0.03, 0.02, -0.03, 0.02, -0.03, -0.11, 0.13};//power 6.83007e+06
const double ISS::angles_70[] = {8, 13.913, 17.8261, 21.7391, 25.6522, 29.5652, 31.4783, 32.3913, 32.3043, 32.2174, 33.1304, 42.0435, 43.9565, 50.8696, 50.7826, 51.6957, 52.6087, 59.5217, 63.4348, 71.3478, 74.2609, 72.1739, 79.087, 88, 96.913, 101.826, 104.739, 98.6522, 101.565, 106.478, 115.391, 119.304, 128.217, 131.13, 131.043, 130.957, 133.87, 142.783, 151.696, 157.609, 158.522, 158.435, 158.348, 165.261, 169.174, 170.087, 170, 173.913, 180.826, 188.739, 188.652, 189.565, 193.478, 202.391, 211.304, 220.217, 229.13, 233.043, 235.957, 236.87, 244.783, 248.696, 252.609, 256.522, 260.435, 264.348, 265.261, 272.174, 276.087, 276, 275.913, 275.826, 275.739, 275.652, 279.565, 283.478, 287.391, 291.304, 295.217, 300.13, 309.043, 317.957, 326.87, 334.783, 338.696, 342.609, 346.522, 350.435, 354.348, 358.261, 358.174, 360.087};
const double ISS::speeds_70[] = {0.13, -0.02, 0.11, -0.07, 0.11, -0.07, 0.1, -0.13, 0.01, -0.13, 0.13, 0.13, 0.07, 0.03, 0.1, -0.13, 0.12, 0.01, 0.06, 0.1, -0.09, 0.01, 0.13, 0.13, 0.13, 0.1, -0.09, -0.01, -0.04, 0.13, 0.13, 0.13, 0.13, -0.09, -0.06, -0.09, 0.13, 0.13, 0.13, -0.02, 0.11, -0.15, 0.12, 0.01, 0.02, -0.11, -0.02, 0.01, 0.13, 0.05, -0.04, -0.07, 0.13, 0.13, 0.13, 0.13, 0.13, 0.1, -0.09, 0.06, 0.11, -0.07, 0.11, -0.07, 0.11, -0.07, 0.02, 0.11, -0.07, 0.05, -0.14, 0.05, -0.14, 0.05, -0.05, 0.05, -0.05, 0.05, -0.05, 0.13, 0.13, 0.13, 0.13, 0.05, 0.07, -0.06, 0.07, -0.06, 0.07, -0.06, -0.09, 0.05};//power 6.86697e+06

const double ISS::angles__72[] = {348, 348.087, 348.174, 348.261, 348.348, 347.435, 347.522, 338.609, 332.696, 327.783, 327.87, 326.957, 327.043, 325.13, 322.217, 315.304, 306.391, 297.478, 288.565, 281.652, 280.739, 278.826, 276.913, 271, 263.087, 267.174, 264.261, 257.348, 259.435, 257.522, 258.609, 254.696, 245.783, 244.87, 242.957, 239.043, 236.13, 231.217, 227.304, 224.391, 219.478, 215.565, 209.652, 201.739, 202.826, 200.913, 196, 192.087, 190.174, 185.261, 181.348, 172.435, 163.522, 154.609, 145.696, 136.783, 131.87, 122.957, 119.043, 115.13, 113.217, 110.304, 105.391, 105.478, 100.565, 98.6522, 93.7391, 93.8261, 95.913, 96, 96.087, 94.1739, 85.2609, 82.3478, 80.4348, 82.5217, 77.6087, 68.6957, 59.7826, 50.8696, 41.9565, 33.0435, 24.1304, 20.2174, 16.3043, 12.3913, 9.47826, 5.56522, 3.65217, 1.73913, 352.826, 349.913};
const double ISS::speeds__72[] = {-0.1, 0.06, -0.14, 0.06, -0.14, 0.06, -0.14, -0.15, -0.15, 0.03, -0.13, 0, -0.12, -0.09, -0.15, -0.15, -0.15, -0.15, -0.15, -0.01, -0.14, -0.04, -0.15, -0.15, -0.05, 0.06, -0.15, -0.01, -0.06, 0.07, -0.12, -0.15, -0.13, -0.03, -0.15, -0.09, -0.15, -0.15, -0.09, -0.15, -0.12, -0.15, -0.15, -0.07, -0.04, -0.15, -0.15, -0.04, -0.15, -0.12, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.14, -0.14, -0.12, -0.09, -0.15, 0.03, -0.13, -0.04, -0.15, -0.1, -0.04, -0.04, -0.1, -0.04, -0.15, -0.13, -0.11, 0.07, -0.1, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.12, -0.15, -0.12, -0.12, -0.15, -0.04, -0.15, -0.13, -0.11};//power 6.75704e+06
*/
const double ISS::angles_70[] = {20, 23.913, 27.8261, 29.7391, 30.6522, 30.5652, 31.4783, 32.3913, 32.3043, 32.2174, 33.1304, 42.0435, 43.9565, 50.8696, 50.7826, 51.6957, 52.6087, 55.5217, 63.4348, 71.3478, 74.2609, 71.1739, 79.087, 88, 96.913, 101.826, 104.739, 98.6522, 101.565, 106.478, 115.391, 119.304, 128.217, 131.13, 131.043, 130.957, 133.87, 142.783, 151.696, 157.609, 158.522, 158.435, 158.348, 165.261, 169.174, 170.087, 168, 168.913, 168.826, 171.739, 179.652, 179.565, 187.478, 191.391, 200.304, 209.217, 218.13, 227.043, 235.957, 244.87, 253.783, 258.696, 260.609, 264.522, 265.435, 274.348, 278.261, 278.174, 277.087, 276, 275.913, 275.826, 275.739, 275.652, 277.565, 283.478, 292.391, 301.304, 310.217, 319.13, 328.043, 336.957, 340.87, 344.783, 348.696, 352.609, 356.522, 0.434783, 358.348, 359.261, 7.17391, 16.087}; const double ISS::speeds_70[] = {0.05, -0.05, 0.06, -0.1, 0.01, -0.13, 0.1, -0.13, 0.01, -0.13, 0.13, 0.13, 0.07, 0.03, -0.09, -0.02, -0.09, 0.1, 0.06, 0.1, -0.09, 0.05, 0.13, 0.13, 0.13, 0.1, -0.09, -0.01, -0.04, 0.13, 0.13, 0.13, 0.13, -0.09, -0.06, -0.09, 0.13, 0.13, 0.13, -0.02, 0.11, -0.15, 0.12, 0.01, 0.1, -0.13, -0.05, -0.06, -0.09, 0.13, 0.05, 0.09, 0.07, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, -0.05, 0.11, -0.07, 0.13, 0.13, -0.07, -0.06, -0.12, -0.06, -0.09, -0.06, -0.09, -0.06, -0.02, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.11, -0.07, 0.11, -0.07, 0.11, -0.07, -0.12, 0.05, 0.13, 0.13};//power 6.94904e+06
const double ISS::angles_71[] = {20, 23.913, 26.8261, 27.7391, 28.6522, 29.5652, 29.4783, 30.3913, 30.3043, 30.2174, 31.1304, 40.0435, 41.9565, 49.8696, 53.7826, 56.6957, 58.6087, 58.5217, 59.4348, 67.3478, 72.2609, 81.1739, 90.087, 94, 98.913, 101.826, 104.739, 98.6522, 102.565, 111.478, 117.391, 118.304, 127.217, 127.13, 127.043, 127.957, 131.87, 140.783, 149.696, 155.609, 155.522, 155.435, 158.348, 167.261, 169.174, 169.087, 169, 168.913, 170.826, 178.739, 178.652, 186.565, 188.478, 197.391, 206.304, 215.217, 224.13, 233.043, 241.957, 250.87, 253.783, 254.696, 256.609, 257.522, 266.435, 273.348, 278.261, 280.174, 279.087, 278, 277.913, 277.826, 277.739, 277.652, 278.565, 278.478, 285.391, 294.304, 303.217, 312.13, 321.043, 329.957, 338.87, 344.783, 348.696, 352.609, 356.522, 359.435, 359.348, 359.261, 8.17391, 16.087}; const double ISS::speeds_71[] = {0.11, -0.07, 0.1, -0.13, 0.1, -0.13, 0.1, -0.13, 0.01, -0.13, 0.13, 0.13, 0.07, 0.09, 0.06, -0.08, 0.01, -0.13, 0.13, 0.05, 0.13, 0.13, 0.13, 0.13, -0.05, 0.1, -0.09, -0.07, 0.13, 0.13, -0.02, 0.13, 0.13, -0.1, -0.04, -0.07, 0.13, 0.13, 0.13, -0.02, -0.06, -0.09, 0.13, 0.13, -0.03, -0.11, -0.03, -0.11, 0.13, 0.05, 0.09, 0.07, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, -0.09, 0.1, -0.11, 0.13, 0.13, 0.13, -0.05, 0.01, -0.15, 0.05, -0.14, 0.05, -0.14, 0.1, -0.13, 0.01, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.11, -0.07, 0.11, -0.07, 0.11, -0.15, 0.13, 0.13, 0.05};//power 6.90649e+06
const double ISS::angles_72[] = {9, 17.913, 20.8261, 24.7391, 27.6522, 27.5652, 28.4783, 28.3913, 28.3043, 37.2174, 38.1304, 38.0435, 46.9565, 52.8696, 54.7826, 54.6957, 55.6087, 55.5217, 57.4348, 64.3478, 73.2609, 82.1739, 91.087, 94, 97.913, 101.826, 104.739, 97.6522, 100.565, 102.478, 105.391, 109.304, 118.217, 125.13, 125.043, 127.957, 136.87, 145.783, 151.696, 145.609, 149.522, 153.435, 159.348, 168.261, 168.174, 167.087, 167, 169.913, 177.826, 177.739, 185.652, 186.565, 190.478, 199.391, 208.304, 217.217, 226.13, 231.043, 239.957, 244.87, 247.783, 250.696, 251.609, 259.522, 263.435, 267.348, 267.261, 273.174, 279.087, 281, 280.913, 279.826, 280.739, 280.652, 280.565, 281.478, 283.391, 288.304, 294.217, 303.13, 312.043, 320.957, 329.87, 338.783, 342.696, 346.609, 350.522, 359.435, 359.348, 0.26087, 359.174, 0.0869565}; const double ISS::speeds_72[] = {0.13, 0.13, 0.05, -0.05, 0.01, -0.13, 0.11, -0.15, 0.13, 0.13, -0.13, 0.13, 0.13, 0.06, -0.1, -0.04, -0.07, -0.08, 0.01, 0.13, 0.13, 0.13, 0.13, 0.07, -0.06, 0.1, -0.09, -0.03, -0.02, 0.04, -0.07, 0.13, 0.13, 0.01, -0.09, 0.13, 0.13, 0.13, -0.02, -0.04, 0.03, -0.02, 0.13, 0.13, -0.12, -0.06, -0.09, 0.13, 0.05, 0.09, 0.07, -0.07, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, -0.05, 0.1, -0.09, 0.13, 0.05, 0.11, -0.07, -0.02, 0.11, -0.02, -0.04, -0.1, -0.08, -0.03, -0.11, -0.02, -0.09, 0.05, -0.02, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, 0.11, -0.07, 0.13, 0.13, -0.07, -0.04, -0.13, 0.13};//power 6.83047e+06
const double ISS::angles_73[] = {9, 8.91304, 17.8261, 21.7391, 24.6522, 26.5652, 26.4783, 27.3913, 27.3043, 35.2174, 37.1304, 46.0435, 50.9565, 51.8696, 53.7826, 53.6957, 54.6087, 57.5217, 61.4348, 70.3478, 79.2609, 87.1739, 89.087, 92, 97.913, 101.826, 103.739, 97.6522, 102.565, 111.478, 117.391, 112.304, 116.217, 120.13, 125.043, 133.957, 142.87, 149.783, 150.696, 150.609, 150.522, 151.435, 155.348, 162.261, 163.174, 166.087, 168, 175.913, 177.826, 181.739, 185.652, 188.565, 197.478, 206.391, 215.304, 224.217, 227.13, 228.043, 236.957, 239.87, 244.783, 247.696, 251.609, 255.522, 259.435, 263.348, 267.261, 270.174, 274.087, 275, 283.913, 283.826, 283.739, 283.652, 284.565, 284.478, 286.391, 291.304, 296.217, 300.13, 304.043, 312.957, 321.87, 330.783, 339.696, 347.609, 351.522, 0.434783, 0.347826, 0.26087, 0.173913, 4.08696}; const double ISS::speeds_73[] = {-0.03, 0.13, 0.13, -0.07, 0.1, -0.11, 0.1, -0.13, 0.13, 0.05, 0.13, 0.13, -0.05, -0.05, -0.03, -0.11, 0.04, -0.07, 0.13, 0.13, 0.13, 0.05, -0.09, 0.11, -0.02, 0.1, -0.11, -0.05, 0.13, 0.13, -0.02, -0.05, 0.05, -0.05, 0.13, 0.13, 0.13, 0.01, -0.04, -0.1, -0.04, -0.07, 0.12, 0.01, 0.1, -0.09, 0.13, 0.05, -0.07, 0.11, -0.07, 0.13, 0.13, 0.13, 0.13, 0.13, -0.09, 0.13, 0.13, 0.09, -0.04, 0.11, -0.07, 0.11, -0.07, 0.11, -0.07, 0.11, -0.07, 0.13, 0.13, -0.07, -0.08, -0.07, -0.04, -0.1, 0.09, -0.04, 0.11, -0.07, 0.13, 0.13, 0.13, 0.13, 0.13, 0.05, 0.13, 0.13, -0.06, -0.09, -0.05, 0.06};//power 6.66253e+06
const double ISS::angles_74[] = {9, 12.913, 17.8261, 21.7391, 24.6522, 25.5652, 25.4783, 26.3913, 25.3043, 26.2174, 34.1304, 43.0435, 48.9565, 49.8696, 50.7826, 52.6957, 55.6087, 57.5217, 60.4348, 69.3478, 78.2609, 87.1739, 91.087, 92, 90.913, 99.8261, 104.739, 106.652, 109.565, 114.478, 117.391, 119.304, 120.217, 120.13, 123.043, 130.957, 139.87, 148.783, 149.696, 148.609, 149.522, 151.435, 155.348, 158.261, 165.174, 166.087, 168, 175.913, 176.826, 183.739, 185.652, 194.565, 203.478, 212.391, 221.304, 224.217, 225.13, 234.043, 236.957, 239.87, 241.783, 248.696, 252.609, 256.522, 260.435, 263.348, 268.261, 269.174, 273.087, 271, 277.913, 286.826, 287.739, 287.652, 287.565, 287.478, 288.391, 289.304, 298.217, 302.13, 306.043, 314.957, 323.87, 332.783, 341.696, 348.609, 351.522, 354.435, 2.34783, 2.26087, 2.17391, 4.08696}; const double ISS::speeds_74[] = {0.13, 0, 0.02, -0.03, -0.02, -0.09, -0.05, -0.06, -0.12, 0.05, 0.13, 0.13, -0.02, -0.09, -0.02, -0.06, 0.03, -0.09, 0.13, 0.13, 0.13, 0.13, 0.1, -0.13, 0.13, 0.13, -0.03, -0.05, 0.01, 0.01, -0.05, -0.03, -0.08, -0.07, 0.05, 0.13, 0.13, 0.13, -0.13, 0.02, -0.11, 0.11, -0.07, 0.09, 0.02, -0.11, 0.13, 0.05, 0.12, 0.01, 0.13, 0.13, 0.13, 0.13, 0.13, -0.09, 0.13, 0.13, 0.06, -0.08, 0.02, 0.11, -0.07, 0.11, -0.07, 0.13, -0.05, 0.11, -0.07, 0.01, 0.13, 0.13, -0.13, 0.05, -0.14, 0.1, -0.13, 0.13, 0.13, -0.07, 0.13, 0.13, 0.13, 0.13, 0.13, 0.1, -0.09, 0.13, 0.05, -0.11, -0.03, -0.05};//power 6.45923e+06
const double ISS::angles_75[] = {9, 12.913, 17.8261, 21.7391, 23.6522, 24.5652, 31.4783, 25.3913, 25.3043, 33.2174, 42.1304, 47.0435, 47.9565, 48.8696, 50.7826, 53.6957, 54.6087, 57.5217, 66.4348, 75.3478, 84.2609, 86.1739, 84.087, 86, 89.913, 93.8261, 102.739, 109.652, 118.565, 117.478, 118.391, 119.304, 119.217, 120.13, 123.043, 127.957, 136.87, 145.783, 147.696, 147.609, 148.522, 153.435, 155.348, 164.261, 166.174, 166.087, 169, 174.913, 176.826, 182.739, 184.652, 193.565, 202.478, 211.391, 220.304, 222.217, 229.13, 233.043, 235.957, 240.87, 244.783, 246.696, 252.609, 256.522, 260.435, 263.348, 268.261, 271.174, 270.087, 271, 271.913, 270.826, 271.739, 275.652, 284.565, 290.478, 290.391, 291.304, 294.217, 300.13, 305.043, 306.957, 315.87, 324.783, 333.696, 342.609, 351.522, 354.435, 354.348, 3.26087, 4.17391, 6.08696}; const double ISS::speeds_75[] = {0.1, 0.13, -0.05, 0.1, -0.11, 0.12, 0.01, -0.14, 0.05, 0.13, 0.13, -0.05, -0.06, -0.05, -0.03, -0.02, -0.09, 0.13, 0.13, 0.13, 0.13, -0.1, -0.11, 0.11, -0.07, 0.13, 0.13, 0.13, 0.13, -0.13, 0.1, -0.04, -0.1, 0.01, -0.05, 0.13, 0.13, 0.13, 0.01, -0.13, 0.13, -0.05, 0.13, 0.13, -0.06, -0.09, 0.11, -0.02, 0.11, -0.02, 0.13, 0.13, 0.13, 0.13, 0.13, 0.07, 0.03, -0.01, -0.04, 0.11, -0.07, 0.11, -0.02, 0.07, -0.06, 0.03, -0.01, -0.04, -0.13, 0.1, -0.13, -0.04, -0.07, 0.13, 0.13, -0.02, -0.08, -0.03, -0.02, 0.13, -0.05, 0.13, 0.13, 0.13, 0.13, 0.13, 0.13, -0.09, 0.13, 0.13, 0.03, -0.09};//power 6.24001e+06
const double ISS::angles__70[] = {348, 349.087, 349.174, 347.261, 347.348, 347.435, 346.522, 347.609, 346.696, 344.783, 335.87, 326.957, 325.043, 324.13, 325.217, 321.304, 317.391, 308.478, 299.565, 290.652, 281.739, 276.826, 273.913, 271, 269.087, 267.174, 264.261, 257.348, 260.435, 257.522, 255.609, 258.696, 254.783, 250.87, 242.957, 243.043, 239.13, 235.217, 231.304, 227.391, 218.478, 210.565, 208.652, 199.739, 197.826, 198.913, 198, 196.087, 192.174, 183.261, 175.348, 175.435, 174.522, 165.609, 156.696, 147.783, 138.87, 129.957, 122.043, 113.13, 105.217, 101.304, 100.391, 93.4783, 89.5652, 87.6522, 88.7391, 89.8261, 90.913, 91, 90.087, 90.1739, 89.2609, 88.3478, 84.4348, 75.5217, 66.6087, 58.6957, 49.7826, 40.8696, 31.9565, 23.0435, 19.1304, 15.2174, 11.3043, 7.3913, 3.47826, 1.56522, 355.652, 351.739, 349.826, 350.913}; const double ISS::speeds__70[] = {-0.02, -0.08, -0.06, -0.14, 0.06, -0.14, 0.07, -0.12, -0.04, -0.15, -0.15, -0.13, -0.07, 0.07, -0.12, -0.12, -0.15, -0.15, -0.15, -0.15, -0.15, -0.09, -0.15, -0.09, -0.12, -0.09, -0.15, -0.01, -0.03, -0.15, 0.08, -0.08, -0.12, -0.15, -0.05, -0.09, -0.12, -0.15, -0.12, -0.15, -0.15, -0.06, -0.14, -0.15, -0.01, -0.09, -0.09, -0.12, -0.15, -0.15, -0.12, 0.02, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, 0.02, -0.15, -0.15, -0.1, -0.11, 0.03, -0.11, 0.06, -0.14, 0, -0.12, -0.05, -0.12, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.12, -0.15, -0.12, -0.15, -0.04, -0.15, -0.12, -0.15, 0.07, -0.12};//power 6.87354e+06
const double ISS::angles__71[] = {348, 348.087, 347.174, 347.261, 347.348, 346.435, 347.522, 347.609, 338.696, 329.783, 325.87, 326.957, 325.043, 325.13, 325.217, 321.304, 312.391, 303.478, 294.565, 285.652, 279.739, 276.826, 273.913, 272, 269.087, 267.174, 264.261, 257.348, 259.435, 257.522, 256.609, 256.696, 254.783, 246.87, 240.957, 241.043, 239.13, 235.217, 231.304, 227.391, 222.478, 213.565, 209.652, 200.739, 198.826, 199.913, 200, 196.087, 192.174, 188.261, 184.348, 180.435, 171.522, 162.609, 153.696, 144.783, 135.87, 126.957, 118.043, 113.13, 109.217, 106.304, 104.391, 100.478, 98.5652, 94.6522, 85.7391, 85.8261, 85.913, 85, 87.087, 86.1739, 86.2609, 85.3478, 82.4348, 78.5217, 69.6087, 60.6957, 51.7826, 42.8696, 33.9565, 25.0435, 22.1304, 16.2174, 13.3043, 10.3913, 7.47826, 5.56522, 2.65217, 353.739, 350.826, 348.913}; const double ISS::speeds__71[] = {0.02, -0.11, -0.06, -0.08, -0.06, -0.11, 0.06, -0.14, -0.15, -0.15, -0.01, -0.09, -0.12, 0, -0.12, -0.15, -0.15, -0.15, -0.15, -0.15, -0.09, -0.15, -0.09, -0.12, -0.12, -0.09, -0.15, -0.01, -0.06, -0.07, -0.1, -0.04, -0.15, -0.15, -0.05, -0.09, -0.12, -0.15, -0.12, -0.15, -0.15, -0.14, -0.14, -0.13, -0.07, 0, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.12, -0.15, -0.04, -0.15, -0.09, -0.12, -0.15, -0.14, 0.06, -0.14, 0.04, -0.09, -0.09, -0.05, -0.12, -0.12, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.13, -0.11, -0.12, -0.12, -0.12, -0.12, -0.09, -0.15, -0.15, -0.04, -0.15};//power 6.81432e+06
const double ISS::angles__72[] = {348, 348.087, 348.174, 348.261, 348.348, 347.435, 347.522, 338.609, 332.696, 327.783, 327.87, 326.957, 327.043, 325.13, 322.217, 315.304, 306.391, 297.478, 288.565, 281.652, 280.739, 278.826, 276.913, 271, 263.087, 267.174, 264.261, 257.348, 259.435, 257.522, 258.609, 254.696, 245.783, 244.87, 242.957, 239.043, 236.13, 231.217, 227.304, 224.391, 219.478, 215.565, 209.652, 201.739, 202.826, 200.913, 196, 192.087, 190.174, 185.261, 181.348, 172.435, 163.522, 154.609, 145.696, 136.783, 131.87, 122.957, 119.043, 115.13, 113.217, 110.304, 105.391, 105.478, 100.565, 98.6522, 93.7391, 93.8261, 95.913, 96, 96.087, 94.1739, 85.2609, 82.3478, 80.4348, 82.5217, 77.6087, 68.6957, 59.7826, 50.8696, 41.9565, 33.0435, 24.1304, 20.2174, 16.3043, 12.3913, 9.47826, 5.56522, 3.65217, 1.73913, 352.826, 349.913}; const double ISS::speeds__72[] = {-0.1, 0.06, -0.14, 0.06, -0.14, 0.06, -0.14, -0.15, -0.15, 0.03, -0.13, 0, -0.12, -0.09, -0.15, -0.15, -0.15, -0.15, -0.15, -0.01, -0.14, -0.04, -0.15, -0.15, -0.05, 0.06, -0.15, -0.01, -0.06, 0.07, -0.12, -0.15, -0.13, -0.03, -0.15, -0.09, -0.15, -0.15, -0.09, -0.15, -0.12, -0.15, -0.15, -0.07, -0.04, -0.15, -0.15, -0.04, -0.15, -0.12, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.14, -0.14, -0.12, -0.09, -0.15, 0.03, -0.13, -0.04, -0.15, -0.1, -0.04, -0.04, -0.1, -0.04, -0.15, -0.13, -0.11, 0.07, -0.1, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.15, -0.12, -0.15, -0.12, -0.12, -0.15, -0.04, -0.15, -0.13, -0.11};//power 6.75704e+06
const double ISS::angles__73[] = {350, 349.087, 348.174, 348.261, 339.348, 334.435, 332.522, 330.609, 331.696, 329.783, 328.87, 326.957, 323.043, 319.13, 315.217, 306.304, 297.391, 289.478, 287.565, 284.652, 278.739, 269.826, 263.913, 271, 269.087, 267.174, 264.261, 257.348, 260.435, 256.522, 252.609, 248.696, 244.783, 240.87, 236.957, 233.043, 229.13, 225.217, 221.304, 217.391, 213.478, 209.565, 205.652, 201.739, 197.826, 190.913, 191, 186.087, 186.174, 178.261, 169.348, 165.435, 156.522, 147.609, 138.696, 134.783, 130.87, 129.957, 123.043, 119.13, 115.217, 113.304, 112.391, 103.478, 99.5652, 95.6522, 96.7391, 93.8261, 95.913, 97, 96.087, 92.1739, 83.2609, 81.3478, 80.4348, 76.5217, 71.6087, 66.6957, 64.7826, 57.8696, 48.9565, 40.0435, 31.1304, 23.2174, 21.3043, 15.3913, 11.4783, 9.56522, 6.65217, 5.73913, 1.82609, 352.913}; const double ISS::speeds__73[] = {0.02, -0.15, 0.06, -0.14, -0.15, -0.04, -0.15, 0.07, -0.12, -0.09, -0.09, -0.12, -0.15, -0.12, -0.15, -0.15, -0.15, -0.12, -0.09, -0.15, -0.15, -0.15, 0.02, 0.11, -0.12, -0.09, -0.15, -0.01, -0.03, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.02, -0.11, 0.03, -0.13, -0.15, -0.14, -0.14, -0.15, -0.15, -0.14, -0.14, 0.02, -0.15, -0.15, -0.12, -0.15, 0.02, -0.15, -0.14, -0.14, 0.07, -0.12, -0.01, -0.06, -0.05, -0.12, -0.15, -0.14, -0.05, -0.12, -0.15, -0.15, -0.04, -0.15, -0.15, -0.15, -0.15, -0.15, -0.06, -0.14, -0.15, -0.04, -0.15, -0.05, -0.12, -0.15, -0.15};//power 6.61566e+06
const double ISS::angles__74[] = {350, 349.087, 348.174, 340.261, 338.348, 334.435, 332.522, 332.609, 332.696, 330.783, 330.87, 326.957, 323.043, 319.13, 315.217, 311.304, 307.391, 298.478, 289.565, 280.652, 271.739, 267.826, 263.913, 262, 260.087, 267.174, 264.261, 263.348, 260.435, 253.522, 250.609, 246.696, 244.783, 240.87, 236.957, 233.043, 229.13, 225.217, 221.304, 217.391, 213.478, 211.565, 205.652, 200.739, 197.826, 190.913, 190, 187.087, 187.174, 179.261, 170.348, 166.435, 157.522, 148.609, 139.696, 134.783, 130.87, 126.957, 123.043, 119.13, 115.217, 111.304, 107.391, 103.478, 99.5652, 96.6522, 98.7391, 98.8261, 98.913, 97, 96.087, 88.1739, 79.2609, 78.3478, 78.4348, 76.5217, 72.6087, 68.6957, 64.7826, 60.8696, 56.9565, 48.0435, 39.1304, 30.2174, 21.3043, 17.3913, 11.4783, 9.56522, 6.65217, 6.73913, 6.82609, 357.913}; const double ISS::speeds__74[] = {-0.15, 0.02, -0.15, -0.06, -0.14, -0.06, -0.14, 0.06, -0.14, 0.06, -0.14, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.15, -0.15, -0.15, -0.14, -0.14, -0.04, -0.15, 0.11, 0.02, -0.09, -0.09, -0.15, -0.09, -0.15, -0.09, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.04, -0.15, -0.15, -0.09, -0.15, -0.01, -0.14, 0.06, -0.14, -0.15, -0.14, -0.14, -0.15, -0.15, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, 0.07, -0.1, 0.06, -0.14, 0.02, -0.15, -0.15, -0.13, -0.03, -0.09, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.15, -0.15, -0.15, -0.14, -0.14, -0.11, -0.1, -0.14, 0.06, -0.14, -0.15};//power 6.42658e+06
const double ISS::angles__75[] = {351, 349.087, 348.174, 340.261, 338.348, 335.435, 334.522, 335.609, 334.696, 333.783, 329.87, 326.957, 323.043, 319.13, 313.217, 311.304, 303.391, 294.478, 285.565, 276.652, 274.739, 269.826, 266.913, 262, 260.087, 268.174, 265.261, 263.348, 260.435, 251.522, 248.609, 247.696, 244.783, 240.87, 236.957, 233.043, 229.13, 225.217, 221.304, 217.391, 214.478, 209.565, 205.652, 201.739, 197.826, 196.913, 191, 186.087, 182.174, 180.261, 171.348, 167.435, 158.522, 149.609, 140.696, 135.783, 131.87, 127.957, 125.043, 122.13, 121.217, 112.304, 109.391, 105.478, 100.565, 96.6522, 96.7391, 91.8261, 95.913, 96, 96.087, 89.1739, 80.2609, 74.3478, 74.4348, 74.5217, 72.6087, 68.6957, 64.7826, 60.8696, 56.9565, 48.0435, 39.1304, 30.2174, 21.3043, 18.3913, 14.4783, 9.56522, 7.65217, 7.73913, 6.82609, 357.913}; const double ISS::speeds__75[] = {-0.15, 0.02, -0.15, -0.12, -0.09, -0.15, 0.13, -0.13, 0.02, -0.15, -0.09, -0.15, -0.12, -0.15, -0.04, -0.15, -0.15, -0.15, -0.15, -0.13, -0.07, -0.09, -0.15, -0.15, 0.1, 0.07, -0.12, -0.09, -0.15, -0.15, -0.09, -0.09, -0.15, -0.12, -0.15, -0.12, -0.15, -0.12, -0.15, -0.09, -0.15, -0.15, -0.12, -0.15, 0.02, -0.15, -0.15, -0.15, -0.04, -0.15, -0.14, -0.14, -0.15, -0.15, -0.15, -0.12, -0.15, -0.09, -0.15, 0.02, -0.15, -0.13, -0.11, -0.15, -0.15, 0.06, -0.14, 0.04, -0.04, 0.06, -0.14, -0.15, -0.15, -0.04, -0.1, -0.04, -0.15, -0.12, -0.15, -0.12, -0.15, -0.15, -0.15, -0.15, -0.13, -0.11, -0.15, -0.09, -0.12, 0.02, -0.15, -0.15};//power 6.21963e+06


using namespace std;

int main()
{
    double beta;
    cin >> beta;
    ISS obj;
    cout << obj.getInitialOrientation(beta) << endl;
    cout.flush();

    for (int minute = 0; minute < 92; minute ++) {
       vector<double> data = obj.getStateAtMinute(minute);
       cout << "1" << endl;
       for (int i = 0; i < 20; i ++) {
           cout << data[i] << endl;
       }
       cout.flush();
    }
    return 0;
}

